@@ -29,7 +29,7 @@ CPAN::Testers::ParseReport - parse reports to www.cpantesters.org from various s
 
 =cut
 
-use version; our $VERSION = qv('0.1.9');
+use version; our $VERSION = qv('0.1.10');
 
 =head1 SYNOPSIS
 
@@ -490,6 +490,7 @@ sub parse_report {
     my $expect_prereq = 0;
     my $expect_toolchain = 0;
     my $expecting_toolchain_soon = 0;
+    my $fallback_p5 = "";
 
     my $in_summary = 0;
     my $in_summary_seen_platform = 0;
@@ -605,6 +606,9 @@ sub parse_report {
                     $extract{"meta:writer"} = "CPANPLUS $1";
                 } elsif (/created (?:automatically )?by (\S+)/) {
                     $extract{"meta:writer"} = $1;
+                    if (/\s+on\s+perl\s+(\S+),/) {
+                        $fallback_p5 = $1;
+                    }
                 } elsif (/This report was machine-generated by (\S+) (\S+)/) {
                     $extract{"meta:writer"} = "$1 $2";
                 }
@@ -772,6 +776,9 @@ sub parse_report {
             $expecting_toolchain_soon=1;
         }
     }                           # LINE
+    if (! $extract{"meta:perl"} && $fallback_p5) {
+        $extract{"meta:perl"} = $fallback_p5;
+    }
     if ($Opt{solve}) {
         $extract{id} = $id;
         if ($extract{"conf:osvers"} && $extract{"conf:archname"}) {
@@ -851,6 +858,10 @@ sub _get_cooked_report {
         }
         close $fh;
     }
+    if ($report =~ /\r\n/) {
+        my @rlines = split /\r?\n/, $report;
+        $report = join "\n", @rlines;
+    }
     ($report, $isHTML);
 }
 
